import React, { Component } from "react";
import { withStyles } from "@material-ui/core/styles";
import {
  Dialog,
  Button,
  DialogActions,
  DialogContent,
  DialogContentText,
  DialogTitle,
  Paper,
  InputBase,
  Divider,
  IconButton
} from "@material-ui/core";
import AppBra from "../../components/AppBra";
import { withRouter } from "react-router-dom";
import compose from "recompose/compose";
import { DatePicker } from "@material-ui/pickers";
import { injectIntl, FormattedRelativeTime } from "react-intl";
import { th } from "date-fns/locale";
import { format } from "date-fns";
import { MenuIcon } from "@material-ui/icons/Menu";
import TextField from "@material-ui/core/TextField";
import SearchIcon from "@material-ui/icons/Search";
import DirectionsIcon from "@material-ui/icons/Directions";

const styles = theme => ({
  root: {
    height: 150,
    flexGrow: 1,
    transform: "translateZ(0)",
    // The position fixed scoping doesn't work in IE 11.
    // Disable this demo to preserve the others.
    "@media all and (-ms-high-contrast: none)": {
      display: "none"
    },
    padding: "2px 4px",
    display: "flex",
    alignItems: "center",
    width: 400
  },
  input: {
    marginLeft: theme.spacing(1),
    flex: 1
  },
  iconButton: {
    padding: 10
  },
  divider: {
    height: 28,
    margin: 4
  },
  modal: {
    display: "flex",
    padding: theme.spacing(1),
    alignItems: "center",
    justifyContent: "center"
  }
});

class HomePage extends Component {
  state = {
    tab: 0,
    date: new Date(),
    open: false
  };
  handleClickOpen = () => {
    this.setState({
      open: true
    });
  };
  handleClose = () => {
    this.setState({
      open: false
    });
  };

  componentDidMount = () => {
    let { pathname } = this.props.location;
    pathname = pathname.substring(1, pathname.length);
    // console.log('pathname', pathname)
    const tab =
      pathname === "spa"
        ? 0
        : pathname === "tab2"
        ? 1
        : pathname === "tab3"
        ? 2
        : pathname === "tab4"
        ? 3
        : pathname === "tab5"
        ? 4
        : pathname === "tab6"
        ? 5
        : 0;
    //   7

    this.setState({
      tab: tab
    });
  };

  handleChangeTab = (event, newValue) => {
    const tab =
      newValue === 0
        ? "spa"
        : newValue === 1
        ? "tab2"
        : newValue === 2
        ? "tab3"
        : newValue === 3
        ? "tab4"
        : newValue === 4
        ? "tab5"
        : newValue === 5
        ? "tab6"
        : "spa";
    this.setState({ tab: newValue });
    // this.props.history.push(`/${tab}`);
  };

  handleChangeDate = newDate => {
    console.log("newDate: ", newDate);
    this.setState({
      date: newDate
    });
  };

  render() {
    const { classes } = this.props;
    // const tab = this.state.tab;
    // หรือ
    const { tab, date, open, value } = this.state;
    return (
      <div>
        <AppBra tab={tab} handleChangeTab={this.handleChangeTab} />
        <div className="row center">
          <div className="row mt-2 mb-2">
            <div>
              <Paper component="form" className={classes.root}>
                <IconButton className={classes.iconButton} aria-label="menu">
                  <MenuIcon />
                </IconButton>
                <InputBase
                  className={classes.input}
                  placeholder="Search Google Maps"
                  inputProps={{ "aria-label": "search google maps" }}
                />
                <IconButton
                  type="submit"
                  className={classes.iconButton}
                  aria-label="search"
                >
                  <SearchIcon />
                </IconButton>
                <Divider className={classes.divider} orientation="vertical" />
                <IconButton
                  color="primary"
                  className={classes.iconButton}
                  aria-label="directions"
                >
                  <DirectionsIcon />
                </IconButton>
              </Paper>
            </div>
          </div>
          <div className="row mt-2 mb-2">
            <div className="col s12 m6 l6">
              <h3>ชื่อ</h3>
            </div>
          </div>
          <div className="row mt-2 mb-2">
            <div className="col s12 m6 l6">
              <img
                src="https://www.smeleader.com/wp-content/uploads/2018/05/%E0%B9%81%E0%B8%9F%E0%B8%A3%E0%B8%99%E0%B9%84%E0%B8%8A%E0%B8%AA%E0%B9%8C%E0%B8%A3%E0%B9%89%E0%B8%B2%E0%B8%99%E0%B9%80%E0%B8%AA%E0%B8%A3%E0%B8%B4%E0%B8%A1%E0%B8%AA%E0%B8%A7%E0%B8%A2-%E0%B8%A3%E0%B8%A7%E0%B8%A1%E0%B9%81%E0%B8%9A%E0%B8%A3%E0%B8%99%E0%B8%94%E0%B9%8C%E0%B8%A3%E0%B9%89%E0%B8%B2%E0%B8%99%E0%B8%8B%E0%B8%B2%E0%B8%A5%E0%B8%AD%E0%B8%99-%E0%B8%AA%E0%B8%B2%E0%B8%99%E0%B8%9D%E0%B8%B1%E0%B8%99%E0%B8%98%E0%B8%B8%E0%B8%A3%E0%B8%81%E0%B8%B4%E0%B8%88%E0%B8%97%E0%B8%A3%E0%B8%87%E0%B8%9C%E0%B8%A1.jpg"
                width="70%"
              ></img>
            </div>

            <div className="col s12 m6 l6">
              <div className="row">
                <h4>ที่อยู่ร้าน</h4>
              </div>

              <div className="row">
                <Button
                  variant="outlined"
                  color="primary"
                  onClick={this.handleClickOpen}
                >
                  จองคิว
                </Button>
                <Dialog
                  open={open}
                  onClose={this.handleClose}
                  aria-labelledby="alert-dialog-title"
                  aria-describedby="alert-dialog-description"
                >
                  <DialogTitle id="alert-dialog-title">{"จองคิว"}</DialogTitle>
                  <DialogContent>
                    <h6>
                      วันที่ที่เลือกคือ{" "}
                      {format(new Date(date), "dd MMMM yyyy", {
                        locale: th
                      })}
                    </h6>
                    <DatePicker
                      autoOk
                      orientation="static"
                      variant="static"
                      openTo="date"
                      minDate={new Date()}
                      value={date}
                      onChange={this.handleChangeDate}
                    />
                  </DialogContent>
                  <DialogActions>
                    <Button onClick={this.handleClose} color="primary">
                      Disagree
                    </Button>
                    <Button
                      onClick={this.handleClose}
                      color="primary"
                      autoFocus
                    >
                      Agree
                    </Button>
                  </DialogActions>
                </Dialog>
              </div>
            </div>
          </div>
        </div>
      </div>
    );
  }
}

export default compose(withStyles(styles), withRouter)(HomePage);
